(* Guestfs Browser.
 * Copyright (C) 2010 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *)

(** Tree model for displaying files in the guest filesystem.

    The model reads files and directories on demand so that we don't
    have to read the whole thing in at the beginning.

    Originally this was written as a custom tree model, but we
    couldn't get that to work.  Instead we use something similar
    to this trick:
    http://mail.gnome.org/archives/gtk-app-devel-list/2003-May/msg00241.html *)

type t
  (** A filetree widget.  Actually an opaque object which contains the
      widget and other data.  Use the accessors below. *)

val create : packing:(GObj.widget -> unit) -> unit -> t
  (** Create a new filetree widget (empty).

      [~packing] is the required packing for the widget. *)

val clear : t -> unit
  (** Clear out all rows in existing widget. *)

val add : t -> string -> Slave.inspection_data -> unit
  (** [add t name data] clears out the widget and adds the operating
      system and/or filesystems described by the [data] struct.

      The [name] parameter should be some host-side (verifiable) name,
      not any untrusted string from the guest; usually we pass the
      name of the guest from libvirt here. *)
