(* Guestfs Browser.
 * Copyright (C) 2010 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *)

(** Deals with generating markup and displaying fields in the file tree.

    The types and functions in this file should be considered
    private to the file tree implementation.

    See {!Filetree} for the full description and public interface. *)

(**/**)

val markup_of_name : ?visited:bool -> Slave.direntry -> string
  (* Create markup for filenames. *)

val markup_of_date : int64 -> string
  (* Create markup for dates. *)

val markup_of_size : int64 -> string
  (* Create markup for sizes. *)

val markup_of_mode : int64 -> string
  (* Create markup for mode (permissions). *)

val markup_of_regkey : ?visited:bool -> Hivex.t -> Hivex.node -> string
  (* Create markup for registry keys. *)

val markup_of_regvalue : ?visited:bool -> Hivex.t -> Hivex.value -> string
  (* Create markup for registry values. *)

val markup_of_regvaluetype : Hivex.t -> Hivex.value -> string
  (* Create markup for registry value types. *)

val markup_of_regvaluesize : Hivex.t -> Hivex.value -> string
  (* Create markup for registry value sizes. *)

val set_visited : Filetree_type.t -> Gtk.tree_iter -> unit
  (* Set a file as visited. *)
